@@ -36,28 +36,34 @@ dodgr_isodists <- function (graph,
                             dlim = NULL,
                             heap = "BHeap") {
 
-    if (is.null (dlim))
+    if (is.null (dlim)) {
         stop ("dlim must be specified")
-    if (!is.numeric (dlim))
+    }
+    if (!is.numeric (dlim)) {
         stop ("dlim must be numeric")
+    }
 
     dat <- iso_pre (graph, from, heap)
 
     # expand dlim to an extra value to capture max boundary
-    if (length (dlim) == 1)
+    if (length (dlim) == 1) {
         dlim_exp <- c (dlim, dlim + dlim / 4) # nocov
-    else
+    } else {
         dlim_exp <- c (dlim, dlim [length (dlim)] + dlim [length (dlim)] -
-                       dlim [length (dlim) - 1])
+            dlim [length (dlim) - 1])
+    }
 
-    d <- rcpp_get_iso (dat$graph, dat$vert_map, dat$from_index$index,
-                       sort (dlim_exp), dat$heap)
+    d <- rcpp_get_iso (
+        dat$graph, dat$vert_map, dat$from_index$index,
+        sort (dlim_exp), dat$heap
+    )
     d [d > max (dlim)] <- NA
 
-    if (!is.null (dat$from_index$id))
+    if (!is.null (dat$from_index$id)) {
         rownames (d) <- dat$from_index$id
-    else
-        rownames (d) <- dat$vert_map$vert # nocov
+    } else {
+        rownames (d) <- dat$vert_map$vert
+    } # nocov
     colnames (d) <- dat$vert_map$vert
 
     # verts ON isohulls are flagged with negative values at isodistance;
@@ -79,7 +85,7 @@ iso_pre <- function (graph, from = NULL, heap = "BHeap") {
     graph <- hps$graph
 
     gr_cols <- dodgr_graph_cols (graph)
-    if (is.na (gr_cols$from) | is.na (gr_cols$to)) {
+    if (is.na (gr_cols$from) || is.na (gr_cols$to)) {
         # nocov start - this is only tested on SC, so this never happens
         scols <- find_spatial_cols (graph)
         graph$from_id <- scols$xy_id$xy_fr_id
@@ -91,7 +97,7 @@ iso_pre <- function (graph, from = NULL, heap = "BHeap") {
 
     tp <- attr (graph, "turn_penalty")
     tp <- ifelse (is.null (tp), 0, tp)
-    if (is (graph, "dodgr_streetnet_sc") & tp > 0) {
+    if (is (graph, "dodgr_streetnet_sc") && tp > 0) {
         if (!is.null (from)) {
             from <- nodes_arg_to_pts (from, graph)
             from <- remap_verts_with_turn_penalty (graph, from, from = TRUE)
@@ -102,11 +108,13 @@ iso_pre <- function (graph, from = NULL, heap = "BHeap") {
 
     graph <- convert_graph (graph, gr_cols)
 
-    list (v = v,
-          graph = graph,
-          vert_map = vert_map,
-          from_index = from_index,
-          heap = heap)
+    list (
+        v = v,
+        graph = graph,
+        vert_map = vert_map,
+        from_index = from_index,
+        heap = heap
+    )
 }
 
 #' dodgr_isochrones
@@ -150,9 +158,12 @@ dodgr_isochrones <- function (graph,
                               tlim = NULL,
                               heap = "BHeap") {
 
-    if (!methods::is (graph, "dodgr_streetnet_sc"))
-        stop ("isochrones can only be calculated from SC-class networks ",
-              "generated by osmdata_sc.")
+    if (!methods::is (graph, "dodgr_streetnet_sc")) {
+        stop (
+            "isochrones can only be calculated from SC-class networks ",
+            "generated by osmdata_sc."
+        )
+    }
     graph$d_weighted <- graph$time_weighted
     graph$d <- graph$time
 
@@ -204,11 +215,15 @@ dodgr_isoverts <- function (graph,
                             tlim = NULL,
                             heap = "BHeap") {
 
-    if (!methods::is (graph, "dodgr_streetnet_sc"))
-        stop ("isoverts can only be calculated from SC-class networks ",
-              "generated by osmdata_sc.")
-    if (!is.null (dlim) & !is.null (tlim))
+    if (!methods::is (graph, "dodgr_streetnet_sc")) {
+        stop (
+            "isoverts can only be calculated from SC-class networks ",
+            "generated by osmdata_sc."
+        )
+    }
+    if (!is.null (dlim) && !is.null (tlim)) {
         stop ("Only one of dlim or tlim can be provided")
+    }
 
     has_tlim <- FALSE
     if (!is.null (tlim)) {
@@ -221,22 +236,29 @@ dodgr_isoverts <- function (graph,
     dat <- iso_pre (graph, from, heap)
 
     # expand dlim to an extra value to capture max boundary
-    if (length (dlim) == 1)
+    if (length (dlim) == 1) {
         dlim_exp <- c (dlim, dlim + dlim / 4)
-    else
+    } else {
         dlim_exp <- c (dlim, dlim [length (dlim)] + dlim [length (dlim)] -
-                       dlim [length (dlim) - 1])
+            dlim [length (dlim) - 1])
+    }
 
-    d <- rcpp_get_iso (dat$graph, dat$vert_map, dat$from_index$index,
-                       sort (dlim_exp), dat$heap)
+    d <- rcpp_get_iso (
+        dat$graph,
+        dat$vert_map,
+        dat$from_index$index,
+        sort (dlim_exp),
+        dat$heap
+    )
     d [d > max (dlim)] <- NA
     index <- which (!is.na (d))
     d [index] [d [index] < 0] <- -d [index] [d [index] < 0]
 
-    if (!is.null (dat$from_index$id))
+    if (!is.null (dat$from_index$id)) {
         rownames (d) <- dat$from_index$id
-    else
+    } else {
         rownames (d) <- dat$vert_map$vert
+    }
     colnames (d) <- dat$vert_map$vert
 
     # convert d-values to the *next highest* specified dlim value. breaks need
@@ -248,8 +270,9 @@ dodgr_isoverts <- function (graph,
     d [na_index] <- breaks [-1] [index]
 
     res <- dmat_to_pts (d, dat$from_index$id, dat$v, dlim)
-    if (has_tlim)
+    if (has_tlim) {
         names (res) [names (res) == "dlim"] <- "tlim"
+    }
     return (res)
 }
 
@@ -262,21 +285,26 @@ dmat_to_pts <- function (d, from, v, dlim) {
     for (i in seq (nrow (d))) {
         o <- v [match (from [i], v$id), ]
         pts [[i]] <- lapply (dlim, function (j) {
-                                 res <- pt_names [which (d [i, ] == j)]
-                                 # Then any additional terminal vertices
-                                 index <- which (!d [i, ] %in% dlim &
-                                                 d [i, ] < j)
-                                 res <- c (res, pt_names [index])
-                                 res <- v [match (res, v$id), ]
-                                 if (nrow (res) > 0) {
-                                     res$from <- o$id
-                                     res <- order_points (res, o)
-                                     res$dlim <- j
-                                     res <- res [, c ("from", "dlim",
-                                                      "id", "x", "y")]
-                                 }
-                                 return (res)
-            })
+            res <- pt_names [which (d [i, ] == j)]
+            # Then any additional terminal vertices
+            index <- which (!d [i, ] %in% dlim &
+                d [i, ] < j)
+            res <- c (res, pt_names [index])
+            res <- v [match (res, v$id), ]
+            if (nrow (res) > 0) {
+                res$from <- o$id
+                res <- order_points (res, o)
+                res$dlim <- j
+                res <- res [, c (
+                    "from",
+                    "dlim",
+                    "id",
+                    "x",
+                    "y"
+                )]
+            }
+            return (res)
+        })
         names (pts [[i]]) <- paste (dlim)
     }
     names (pts) <- rownames (d)
